==> igniteui-react-core-18.2.0-beta.0.tgz: package/esm2015/lib/WebColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnDescription = /*@__PURE__*/ (() => {
    class WebColumnDescription extends Description {
        get_type() {
            return "WebColumn";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.bx = null;
            this.b0 = null;
            this.ca = null;
            this.af = false;
            this.ad = false;
            this.w = false;
            this.s = false;
            this.u = false;
            this.ab = false;
            this.o = false;
            this.x = false;
            this.y = false;
            this.ae = false;
            this.q = false;
            this.r = false;
            this.z = false;
            this.cb = null;
            this.a4 = 0;
            this.b5 = null;
            this.b1 = null;
            this.bi = null;
            this.b2 = null;
            this.bh = null;
            this.bs = null;
            this.bt = null;
            this.v = false;
            this.ag = false;
            this.ac = false;
            this.bu = null;
            this.a8 = 0;
            this.a6 = 0;
            this.a9 = 0;
            this.a7 = 0;
            this.bg = null;
            this.a5 = 0;
            this.b6 = null;
            this.aa = false;
            this.bk = null;
            this.j = null;
            this.l = null;
            this.b9 = null;
            this.br = null;
            this.b3 = null;
            this.b4 = null;
            this.bw = null;
            this.by = null;
            this.ah = false;
            this.h = null;
            this.p = false;
            this.t = false;
            this.bv = null;
            this.ai = false;
            this.bj = null;
            this.b7 = null;
            this.bz = null;
            this.b8 = null;
        }
        get field() {
            return this.bx;
        }
        set field(a) {
            this.bx = a;
            this.g("Field");
        }
        get header() {
            return this.b0;
        }
        set header(a) {
            this.b0 = a;
            this.g("Header");
        }
        get title() {
            return this.ca;
        }
        set title(a) {
            this.ca = a;
            this.g("Title");
        }
        get sortable() {
            return this.af;
        }
        set sortable(a) {
            this.af = a;
            this.g("Sortable");
        }
        get selectable() {
            return this.ad;
        }
        set selectable(a) {
            this.ad = a;
            this.g("Selectable");
        }
        get groupable() {
            return this.w;
        }
        set groupable(a) {
            this.w = a;
            this.g("Groupable");
        }
        get editable() {
            return this.s;
        }
        set editable(a) {
            this.s = a;
            this.g("Editable");
        }
        get filterable() {
            return this.u;
        }
        set filterable(a) {
            this.u = a;
            this.g("Filterable");
        }
        get resizable() {
            return this.ab;
        }
        set resizable(a) {
            this.ab = a;
            this.g("Resizable");
        }
        get autosizeHeader() {
            return this.o;
        }
        set autosizeHeader(a) {
            this.o = a;
            this.g("AutosizeHeader");
        }
        get hasSummary() {
            return this.x;
        }
        set hasSummary(a) {
            this.x = a;
            this.g("HasSummary");
        }
        get hidden() {
            return this.y;
        }
        set hidden(a) {
            this.y = a;
            this.g("Hidden");
        }
        get selected() {
            return this.ae;
        }
        set selected(a) {
            this.ae = a;
            this.g("Selected");
        }
        get disableHiding() {
            return this.q;
        }
        set disableHiding(a) {
            this.q = a;
            this.g("DisableHiding");
        }
        get disablePinning() {
            return this.r;
        }
        set disablePinning(a) {
            this.r = a;
            this.g("DisablePinning");
        }
        get movable() {
            return this.z;
        }
        set movable(a) {
            this.z = a;
            this.g("Movable");
        }
        get width() {
            return this.cb;
        }
        set width(a) {
            this.cb = a;
            this.g("Width");
        }
        get autoSize() {
            return this.a4;
        }
        set autoSize(a) {
            this.a4 = a;
            this.g("AutoSize");
        }
        get maxWidth() {
            return this.b5;
        }
        set maxWidth(a) {
            this.b5 = a;
            this.g("MaxWidth");
        }
        get headerClasses() {
            return this.b1;
        }
        set headerClasses(a) {
            this.b1 = a;
            this.g("HeaderClasses");
        }
        get headerStyles() {
            return this.bi;
        }
        set headerStyles(a) {
            this.bi = a;
            this.g("HeaderStyles");
        }
        get headerGroupClasses() {
            return this.b2;
        }
        set headerGroupClasses(a) {
            this.b2 = a;
            this.g("HeaderGroupClasses");
        }
        get headerGroupStyles() {
            return this.bh;
        }
        set headerGroupStyles(a) {
            this.bh = a;
            this.g("HeaderGroupStyles");
        }
        get cellClassesRef() {
            return this.bs;
        }
        set cellClassesRef(a) {
            this.bs = a;
            this.g("CellClassesRef");
        }
        get cellStylesRef() {
            return this.bt;
        }
        set cellStylesRef(a) {
            this.bt = a;
            this.g("CellStylesRef");
        }
        get filteringIgnoreCase() {
            return this.v;
        }
        set filteringIgnoreCase(a) {
            this.v = a;
            this.g("FilteringIgnoreCase");
        }
        get sortingIgnoreCase() {
            return this.ag;
        }
        set sortingIgnoreCase(a) {
            this.ag = a;
            this.g("SortingIgnoreCase");
        }
        get searchable() {
            return this.ac;
        }
        set searchable(a) {
            this.ac = a;
            this.g("Searchable");
        }
        get dataType() {
            return this.bu;
        }
        set dataType(a) {
            this.bu = a;
            this.g("DataType");
        }
        get rowEnd() {
            return this.a8;
        }
        set rowEnd(a) {
            this.a8 = a;
            this.g("RowEnd");
        }
        get colEnd() {
            return this.a6;
        }
        set colEnd(a) {
            this.a6 = a;
            this.g("ColEnd");
        }
        get rowStart() {
            return this.a9;
        }
        set rowStart(a) {
            this.a9 = a;
            this.g("RowStart");
        }
        get colStart() {
            return this.a7;
        }
        set colStart(a) {
            this.a7 = a;
            this.g("ColStart");
        }
        get additionalTemplateContext() {
            return this.bg;
        }
        set additionalTemplateContext(a) {
            this.bg = a;
            this.g("AdditionalTemplateContext");
        }
        get calcPixelWidth() {
            return this.a5;
        }
        set calcPixelWidth(a) {
            this.a5 = a;
            this.g("CalcPixelWidth");
        }
        get minWidth() {
            return this.b6;
        }
        set minWidth(a) {
            this.b6 = a;
            this.g("MinWidth");
        }
        get pinned() {
            return this.aa;
        }
        set pinned(a) {
            this.aa = a;
            this.g("Pinned");
        }
        get summaries() {
            return this.bk;
        }
        set summaries(a) {
            this.bk = a;
            this.g("Summaries");
        }
        get filters() {
            return this.j;
        }
        set filters(a) {
            this.j = a;
            this.g("Filters");
        }
        get sortStrategy() {
            return this.l;
        }
        set sortStrategy(a) {
            this.l = a;
            this.g("SortStrategy");
        }
        get summaryTemplateRef() {
            return this.b9;
        }
        set summaryTemplateRef(a) {
            this.b9 = a;
            this.g("SummaryTemplateRef");
        }
        get bodyTemplateRef() {
            return this.br;
        }
        set bodyTemplateRef(a) {
            this.br = a;
            this.g("BodyTemplateRef");
        }
        get headerTemplateRef() {
            return this.b3;
        }
        set headerTemplateRef(a) {
            this.b3 = a;
            this.g("HeaderTemplateRef");
        }
        get inlineEditorTemplateRef() {
            return this.b4;
        }
        set inlineEditorTemplateRef(a) {
            this.b4 = a;
            this.g("InlineEditorTemplateRef");
        }
        get errorTemplateRef() {
            return this.bw;
        }
        set errorTemplateRef(a) {
            this.bw = a;
            this.g("ErrorTemplateRef");
        }
        get filterCellTemplateRef() {
            return this.by;
        }
        set filterCellTemplateRef(a) {
            this.by = a;
            this.g("FilterCellTemplateRef");
        }
        get visibleWhenCollapsed() {
            return this.ah;
        }
        set visibleWhenCollapsed(a) {
            this.ah = a;
            this.g("VisibleWhenCollapsed");
        }
        get pipeArgs() {
            return this.h;
        }
        set pipeArgs(a) {
            this.h = a;
            this.g("PipeArgs");
        }
        get collapsible() {
            return this.p;
        }
        set collapsible(a) {
            this.p = a;
            this.g("Collapsible");
        }
        get expanded() {
            return this.t;
        }
        set expanded(a) {
            this.t = a;
            this.g("Expanded");
        }
        get defaultWidth() {
            return this.bv;
        }
        set defaultWidth(a) {
            this.bv = a;
            this.g("DefaultWidth");
        }
        get widthSetByUser() {
            return this.ai;
        }
        set widthSetByUser(a) {
            this.ai = a;
            this.g("WidthSetByUser");
        }
        get parentColumn() {
            return this.bj;
        }
        set parentColumn(a) {
            this.bj = a;
            this.g("ParentColumn");
        }
        get name() {
            return this.b7;
        }
        set name(a) {
            this.b7 = a;
            this.g("Name");
        }
        get formatterRef() {
            return this.bz;
        }
        set formatterRef(a) {
            this.bz = a;
            this.g("FormatterRef");
        }
        get summaryFormatterRef() {
            return this.b8;
        }
        set summaryFormatterRef(a) {
            this.b8 = a;
            this.g("SummaryFormatterRef");
        }
    }
    WebColumnDescription.$t = /*@__PURE__*/ markType(WebColumnDescription, 'WebColumnDescription', Description.$);
    WebColumnDescription.__canMarshalByValue = true;
    WebColumnDescription.__marshalByValueAlias = "Column";
    return WebColumnDescription;
})();

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm2015/lib/WebColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnDescription = /*@__PURE__*/ (() => {
    class WebColumnDescription extends Description {
        get_type() {
            return "WebColumn";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.bi = null;
            this.bl = null;
            this.bw = null;
            this.ac = false;
            this.aa = false;
            this.u = false;
            this.r = false;
            this.s = false;
            this.y = false;
            this.o = false;
            this.v = false;
            this.w = false;
            this.ab = false;
            this.p = false;
            this.q = false;
            this.bx = null;
            this.bq = null;
            this.bm = null;
            this.a6 = null;
            this.bn = null;
            this.a5 = null;
            this.be = null;
            this.bf = null;
            this.bk = null;
            this.bu = null;
            this.t = false;
            this.ad = false;
            this.z = false;
            this.bg = null;
            this.ay = 0;
            this.aw = 0;
            this.az = 0;
            this.ax = 0;
            this.a4 = null;
            this.br = null;
            this.x = false;
            this.bt = null;
            this.j = null;
            this.l = null;
            this.bv = null;
            this.bd = null;
            this.bo = null;
            this.bp = null;
            this.bh = null;
            this.bj = null;
            this.ae = false;
            this.h = null;
            this.a7 = null;
            this.bs = null;
        }
        get field() {
            return this.bi;
        }
        set field(a) {
            this.bi = a;
            this.g("Field");
        }
        get header() {
            return this.bl;
        }
        set header(a) {
            this.bl = a;
            this.g("Header");
        }
        get title() {
            return this.bw;
        }
        set title(a) {
            this.bw = a;
            this.g("Title");
        }
        get sortable() {
            return this.ac;
        }
        set sortable(a) {
            this.ac = a;
            this.g("Sortable");
        }
        get selectable() {
            return this.aa;
        }
        set selectable(a) {
            this.aa = a;
            this.g("Selectable");
        }
        get groupable() {
            return this.u;
        }
        set groupable(a) {
            this.u = a;
            this.g("Groupable");
        }
        get editable() {
            return this.r;
        }
        set editable(a) {
            this.r = a;
            this.g("Editable");
        }
        get filterable() {
            return this.s;
        }
        set filterable(a) {
            this.s = a;
            this.g("Filterable");
        }
        get resizable() {
            return this.y;
        }
        set resizable(a) {
            this.y = a;
            this.g("Resizable");
        }
        get autosizeHeader() {
            return this.o;
        }
        set autosizeHeader(a) {
            this.o = a;
            this.g("AutosizeHeader");
        }
        get hasSummary() {
            return this.v;
        }
        set hasSummary(a) {
            this.v = a;
            this.g("HasSummary");
        }
        get hidden() {
            return this.w;
        }
        set hidden(a) {
            this.w = a;
            this.g("Hidden");
        }
        get selected() {
            return this.ab;
        }
        set selected(a) {
            this.ab = a;
            this.g("Selected");
        }
        get disableHiding() {
            return this.p;
        }
        set disableHiding(a) {
            this.p = a;
            this.g("DisableHiding");
        }
        get disablePinning() {
            return this.q;
        }
        set disablePinning(a) {
            this.q = a;
            this.g("DisablePinning");
        }
        get width() {
            return this.bx;
        }
        set width(a) {
            this.bx = a;
            this.g("Width");
        }
        get maxWidth() {
            return this.bq;
        }
        set maxWidth(a) {
            this.bq = a;
            this.g("MaxWidth");
        }
        get headerClasses() {
            return this.bm;
        }
        set headerClasses(a) {
            this.bm = a;
            this.g("HeaderClasses");
        }
        get headerStyles() {
            return this.a6;
        }
        set headerStyles(a) {
            this.a6 = a;
            this.g("HeaderStyles");
        }
        get headerGroupClasses() {
            return this.bn;
        }
        set headerGroupClasses(a) {
            this.bn = a;
            this.g("HeaderGroupClasses");
        }
        get headerGroupStyles() {
            return this.a5;
        }
        set headerGroupStyles(a) {
            this.a5 = a;
            this.g("HeaderGroupStyles");
        }
        get cellClassesRef() {
            return this.be;
        }
        set cellClassesRef(a) {
            this.be = a;
            this.g("CellClassesRef");
        }
        get cellStylesRef() {
            return this.bf;
        }
        set cellStylesRef(a) {
            this.bf = a;
            this.g("CellStylesRef");
        }
        get formatterRef() {
            return this.bk;
        }
        set formatterRef(a) {
            this.bk = a;
            this.g("FormatterRef");
        }
        get summaryFormatterRef() {
            return this.bu;
        }
        set summaryFormatterRef(a) {
            this.bu = a;
            this.g("SummaryFormatterRef");
        }
        get filteringIgnoreCase() {
            return this.t;
        }
        set filteringIgnoreCase(a) {
            this.t = a;
            this.g("FilteringIgnoreCase");
        }
        get sortingIgnoreCase() {
            return this.ad;
        }
        set sortingIgnoreCase(a) {
            this.ad = a;
            this.g("SortingIgnoreCase");
        }
        get searchable() {
            return this.z;
        }
        set searchable(a) {
            this.z = a;
            this.g("Searchable");
        }
        get dataType() {
            return this.bg;
        }
        set dataType(a) {
            this.bg = a;
            this.g("DataType");
        }
        get rowEnd() {
            return this.ay;
        }
        set rowEnd(a) {
            this.ay = a;
            this.g("RowEnd");
        }
        get colEnd() {
            return this.aw;
        }
        set colEnd(a) {
            this.aw = a;
            this.g("ColEnd");
        }
        get rowStart() {
            return this.az;
        }
        set rowStart(a) {
            this.az = a;
            this.g("RowStart");
        }
        get colStart() {
            return this.ax;
        }
        set colStart(a) {
            this.ax = a;
            this.g("ColStart");
        }
        get additionalTemplateContext() {
            return this.a4;
        }
        set additionalTemplateContext(a) {
            this.a4 = a;
            this.g("AdditionalTemplateContext");
        }
        get minWidth() {
            return this.br;
        }
        set minWidth(a) {
            this.br = a;
            this.g("MinWidth");
        }
        get pinned() {
            return this.x;
        }
        set pinned(a) {
            this.x = a;
            this.g("Pinned");
        }
        get summariesRef() {
            return this.bt;
        }
        set summariesRef(a) {
            this.bt = a;
            this.g("SummariesRef");
        }
        get filters() {
            return this.j;
        }
        set filters(a) {
            this.j = a;
            this.g("Filters");
        }
        get sortStrategy() {
            return this.l;
        }
        set sortStrategy(a) {
            this.l = a;
            this.g("SortStrategy");
        }
        get summaryTemplateRef() {
            return this.bv;
        }
        set summaryTemplateRef(a) {
            this.bv = a;
            this.g("SummaryTemplateRef");
        }
        get bodyTemplateRef() {
            return this.bd;
        }
        set bodyTemplateRef(a) {
            this.bd = a;
            this.g("BodyTemplateRef");
        }
        get headerTemplateRef() {
            return this.bo;
        }
        set headerTemplateRef(a) {
            this.bo = a;
            this.g("HeaderTemplateRef");
        }
        get inlineEditorTemplateRef() {
            return this.bp;
        }
        set inlineEditorTemplateRef(a) {
            this.bp = a;
            this.g("InlineEditorTemplateRef");
        }
        get errorTemplateRef() {
            return this.bh;
        }
        set errorTemplateRef(a) {
            this.bh = a;
            this.g("ErrorTemplateRef");
        }
        get filterCellTemplateRef() {
            return this.bj;
        }
        set filterCellTemplateRef(a) {
            this.bj = a;
            this.g("FilterCellTemplateRef");
        }
        get visibleWhenCollapsed() {
            return this.ae;
        }
        set visibleWhenCollapsed(a) {
            this.ae = a;
            this.g("VisibleWhenCollapsed");
        }
        get pipeArgs() {
            return this.h;
        }
        set pipeArgs(a) {
            this.h = a;
            this.g("PipeArgs");
        }
        get parentColumn() {
            return this.a7;
        }
        set parentColumn(a) {
            this.a7 = a;
            this.g("ParentColumn");
        }
        get name() {
            return this.bs;
        }
        set name(a) {
            this.bs = a;
            this.g("Name");
        }
    }
    WebColumnDescription.$t = /*@__PURE__*/ markType(WebColumnDescription, 'WebColumnDescription', Description.$);
    WebColumnDescription.__canMarshalByValue = true;
    WebColumnDescription.__marshalByValueAlias = "Column";
    return WebColumnDescription;
})();
